Learn R Programming

spatialising (version 0.6.2)

kinetic_ising_exemplar: Exemplar of an Ising model for spatial data

Description

Creates an ensemble of simulations based on the given parameters of the Ising model and selects an exemplar (a model that is closest to the average of the ensemble)

Usage

kinetic_ising_exemplar(runs, ...)

Value

Object of the same class as x

Arguments

runs

A number of simulations to perform

...

Arguments for kinetic_ising()

See Also

kinetic_ising(), kinetic_ising_ensemble()

Examples

Run this code
data(r_start, package = "spatialising")
l = kinetic_ising_exemplar(100, r_start, B = -0.3, J = 0.7)

# \donttest{
  library(terra)
  r1 = rast(system.file("raster/r_start.tif", package = "spatialising"))
  plot(r1)
  r2 = kinetic_ising_exemplar(100, r1, B = -0.3, J = 0.7)
  plot(r2)
# }

Run the code above in your browser using DataLab